@@ -30,7 +30,7 @@ class Image:
 
     def resize(self,image):
         image = np.uint8(image)
-        image = PilImage.fromarray(image).resize((Config.get("IMAGE_WIDTH"), Config.get("IMAGE_HEIGHT")))
+        image = PilImage.fromarray(image).resize((Config("IMAGE_WIDTH"), Config("IMAGE_HEIGHT")))
         return np.array(image)
 
     def normalize(self, image):
@@ -39,9 +39,9 @@ class Image:
     def process(self):
         image = self.decode(self.image)
         image = np.array(image)
-        if Config.get("RESIZE_ENABLED"):
+        if Config("RESIZE_ENABLED"):
             image = self.resize(image)
-        if Config.get("NORMALIZATION_ENABLED"):
+        if Config("NORMALIZATION_ENABLED"):
             image = self.normalize(image)
         image = image[np.newaxis, ..., np.newaxis]
         self.image = image
